@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     AdditionalConstraintsElementType,
@@ -155,7 +155,7 @@ BackendAPIConflictResolutionTypeDef = TypedDict(
 BackendAPIResourceConfigTypeDef = TypedDict(
     "BackendAPIResourceConfigTypeDef",
     {
-        "AdditionalAuthTypes": List["BackendAPIAuthTypeTypeDef"],
+        "AdditionalAuthTypes": Sequence["BackendAPIAuthTypeTypeDef"],
         "ApiName": str,
         "ConflictResolution": "BackendAPIConflictResolutionTypeDef",
         "DefaultAuthType": "BackendAPIAuthTypeTypeDef",
@@ -313,9 +313,9 @@ _RequiredCreateBackendAuthOAuthConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthOAuthConfigTypeDef",
     {
         "OAuthGrantType": OAuthGrantTypeType,
-        "OAuthScopes": List[OAuthScopesElementType],
-        "RedirectSignInURIs": List[str],
-        "RedirectSignOutURIs": List[str],
+        "OAuthScopes": Sequence[OAuthScopesElementType],
+        "RedirectSignInURIs": Sequence[str],
+        "RedirectSignOutURIs": Sequence[str],
     },
 )
 _OptionalCreateBackendAuthOAuthConfigTypeDef = TypedDict(
@@ -343,7 +343,7 @@ _RequiredCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
 _OptionalCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef",
     {
-        "AdditionalConstraints": List[AdditionalConstraintsElementType],
+        "AdditionalConstraints": Sequence[AdditionalConstraintsElementType],
     },
     total=False,
 )
@@ -405,7 +405,7 @@ CreateBackendAuthResponseTypeDef = TypedDict(
 _RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthUserPoolConfigTypeDef",
     {
-        "RequiredSignUpAttributes": List[RequiredSignUpAttributesElementType],
+        "RequiredSignUpAttributes": Sequence[RequiredSignUpAttributesElementType],
         "SignInMethod": SignInMethodType,
         "UserPoolName": str,
     },
@@ -472,7 +472,7 @@ _RequiredCreateBackendRequestRequestTypeDef = TypedDict(
 _OptionalCreateBackendRequestRequestTypeDef = TypedDict(
     "_OptionalCreateBackendRequestRequestTypeDef",
     {
-        "ResourceConfig": Dict[str, Any],
+        "ResourceConfig": Mapping[str, Any],
         "ResourceName": str,
     },
     total=False,
@@ -949,7 +949,7 @@ ResponseMetadataTypeDef = TypedDict(
 SettingsTypeDef = TypedDict(
     "SettingsTypeDef",
     {
-        "MfaTypes": List[MfaTypesElementType],
+        "MfaTypes": Sequence[MfaTypesElementType],
         "SmsMessage": str,
     },
     total=False,
@@ -1042,9 +1042,9 @@ UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
     {
         "DomainPrefix": str,
         "OAuthGrantType": OAuthGrantTypeType,
-        "OAuthScopes": List[OAuthScopesElementType],
-        "RedirectSignInURIs": List[str],
-        "RedirectSignOutURIs": List[str],
+        "OAuthScopes": Sequence[OAuthScopesElementType],
+        "RedirectSignInURIs": Sequence[str],
+        "RedirectSignOutURIs": Sequence[str],
         "SocialProviderSettings": "SocialProviderSettingsTypeDef",
     },
     total=False,
@@ -1053,7 +1053,7 @@ UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
 UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "UpdateBackendAuthPasswordPolicyConfigTypeDef",
     {
-        "AdditionalConstraints": List[AdditionalConstraintsElementType],
+        "AdditionalConstraints": Sequence[AdditionalConstraintsElementType],
         "MinimumLength": float,
     },
     total=False,
